@@ -1,3 +1,5 @@
+#![warn(rust_2018_idioms)]
+
 mod always;
 pub use crate::always::Always;
 mod blackhole;
@@ -11,8 +13,16 @@ pub use crate::maxwell::Maxwell;
 mod mirror;
 pub use crate::mirror::Mirror;
 mod oneway;
-pub use crate::oneway::{OnewayGreater, OnewayLess, OnewayEqual};
+pub use crate::oneway::{OnewayEqual, OnewayGreater, OnewayLess};
 mod pristine;
 pub use crate::pristine::Pristine;
 mod reverse;
 pub use crate::reverse::Reverse;
+mod loaner;
+pub use crate::loaner::Loaner;
+mod comte;
+pub use crate::comte::Comte;
+mod multiplicity;
+pub use crate::multiplicity::Multiplicity;
+mod double;
+pub use crate::double::Double;
