@@ -1,5 +1,17 @@
+/// `Mirror` wraps any existing type which implements [PartialEq]. However
+/// Mirror implements `eq` opposite to its conventional meaning.
+///
+/// # Examples
+///
+/// ```
+/// # use misfortunate::Mirror;
+/// let one = Mirror(1u8);
+/// let two = Mirror(2u8);
+/// assert!(one != one);
+/// assert!(one == two);
+/// ```
 #[derive(Clone, Debug)]
-pub struct Mirror<T: PartialEq>(T);
+pub struct Mirror<T: PartialEq>(pub T);
 
 impl<T: PartialEq> PartialEq for Mirror<T> {
     fn eq(&self, other: &Self) -> bool {
